@@ -527,16 +527,10 @@ class FixtureSpace(namespaces.Namespace):
     into the target instance under the ``_rfm_fixture_registry`` attribute.
     '''
 
-    @property
-    def local_namespace_name(self):
-        return '_rfm_local_fixture_space'
-
-    @property
-    def namespace_name(self):
-        return '_rfm_fixture_space'
-
-    def __init__(self, target_cls=None, target_namespace=None):
-        super().__init__(target_cls, target_namespace)
+    def __init__(self, target_cls=None, illegal_names=None):
+        super().__init__(target_cls, illegal_names,
+                         ns_name='_rfm_fixture_space',
+                         ns_local_name='_rfm_local_fixture_space')
 
         # Store all fixture variant combinations to allow random access.
         self.__variant_combinations = tuple(
@@ -563,7 +557,7 @@ class FixtureSpace(namespaces.Namespace):
 
     def extend(self, cls):
         '''Extend the inherited fixture space with the local fixture space.'''
-        local_fixture_space = getattr(cls, self.local_namespace_name)
+        local_fixture_space = getattr(cls, self.local_namespace_name, False)
         while local_fixture_space:
             name, fixture = local_fixture_space.popitem()
             self.fixtures[name] = fixture
