@@ -393,18 +393,18 @@ class RegressionTestMeta(type):
         for base in (b for b in bases if hasattr(b, '_rfm_dir')):
             cls._rfm_dir.update(base._rfm_dir)
 
-        used_attribute_names = set(cls._rfm_dir)
+        used_attribute_names = set(cls._rfm_dir).union(
+            {h.__name__ for h in cls._rfm_hook_registry}
+        )
 
-        # Build the var space and extend the target namespace
-        variables.VarSpace(cls, used_attribute_names)
-        used_attribute_names.update(cls._rfm_var_space.vars)
-
-        # Build the parameter space
-        parameters.ParamSpace(cls, used_attribute_names)
-        used_attribute_names.update(cls._rfm_param_space.params)
-
-        # Build the fixture space
-        fixtures.FixtureSpace(cls, used_attribute_names)
+        # Build the different global class namespaces
+        namespace_types = (variables.VarSpace,
+                           parameters.ParamSpace,
+                           fixtures.FixtureSpace)
+        for ns_type in namespace_types:
+            ns = ns_type(cls, used_attribute_names)
+            setattr(cls, ns.namespace_name, ns)
+            used_attribute_names.update(ns.data())
 
         # Update used names set with the local __dict__
         cls._rfm_dir.update(cls.__dict__)
